==> ejc-panhuo-api-3.0.0-20200822.032406-26-sources.jar: com/ejianc/business/panhuo/vo/CategoryVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 求购物资明细表
 * 
 * @author generator
 * 
 */
public class CategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long wbuyId; // 求购主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.Long materialCode; // 物资编号
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别末级
    private java.lang.String materialTypeName; // 物资类别末级名称
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String unit; // 单位
    private java.lang.String brand; // 品牌
    private java.math.BigDecimal nums; // 求购数量
    private java.lang.String spec; // 规格型号
    private java.lang.String note; // 备注

    public Long getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(Long materialCode) {
        this.materialCode = materialCode;
    }

    /**
     * 求购主键
     */
    public java.lang.Long getWbuyId() {
        return wbuyId;
    }

    /**
     * 求购主键
     */
    public void setWbuyId(java.lang.Long wbuyId) {
        this.wbuyId = wbuyId;
    }
    /**
     * 物资主键
     */
    @ReferSerialTransfer(referCode="Material001")
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    @ReferDeserialTransfer
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 求购数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 求购数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 备注
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    
}

==> ejc-panhuo-api-3.0.0-20230308.024147-152-sources.jar: com/ejianc/business/panhuo/vo/CategoryVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 求购物资明细表
 * 
 * @author generator
 * 
 */
public class CategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long wbuyId; // 求购主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialCode; // 物资编号
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别末级
    private java.lang.String materialTypeName; // 物资类别末级名称
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String unit; // 单位
    private java.lang.String brand; // 品牌
    private java.math.BigDecimal nums; // 求购数量
    private java.lang.String spec; // 规格型号
    private java.lang.String note; // 备注

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    /**
     * 求购主键
     */
    public java.lang.Long getWbuyId() {
        return wbuyId;
    }

    /**
     * 求购主键
     */
    public void setWbuyId(java.lang.Long wbuyId) {
        this.wbuyId = wbuyId;
    }
    /**
     * 物资主键
     */
    @ReferSerialTransfer(referCode="Material001")
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    @ReferDeserialTransfer
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 求购数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 求购数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getNote() {
        return note;
    }

    /**
     * 备注
     */
    public void setNote(java.lang.String note) {
        this.note = note;
    }
    
}
